@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: statistics
 version: 0.13.2.3
-id: statistics-0.13.2.3-79922f302b6314f617505e5bba748bee
-key: stati_BfilijUy1rQCzi3oaCOEDS
+id: statistics-0.13.2.3-fb2d29ac22ccabf2cfd4165df330c05e
+key: stati_59A5puYT9nSEZ2hnfUQGPw
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -63,9 +63,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/statistics-0.13.2.3
-hs-libraries: HSstatistics-0.13.2.3-BfilijUy1rQCzi3oaCOEDS
+hs-libraries: HSstatistics-0.13.2.3-59A5puYT9nSEZ2hnfUQGPw
 depends:
-    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
